"""
This is the main module of the Discord Bot

Mainly loads the Cog's and starts the bot
"""

__version__ = '0.5'
__author__ = 'Bibin Muttappillil'

# standard library imports
import os
from dotenv import load_dotenv
import sys
import traceback

# discord imports
from discord.ext import commands


# Token stuff
load_dotenv()
TOKEN = os.getenv('DISCORD_TOKEN')
if TOKEN is None:
	print("Missing discord token!")
	exit(1)

bot = commands.Bot(command_prefix=commands.when_mentioned_or('$b '))


@bot.event
async def on_command_error(ctx, error):
	print('Ignoring exception in command {}:'.format(ctx.command), file=sys.stderr)
	traceback.print_exception(type(error), error, error.__traceback__, file=sys.stderr)
	await ctx.message.add_reaction('❌')


@bot.event
async def on_command_completion(ctx):
	await ctx.message.add_reaction('✅')


@bot.command(hidden=True)
@commands.is_owner()
async def load(ctx, ext):
	bot.load_extension(f'cogs.{ext}')
	print(f'cogs.{ext} loaded')


@bot.command(hidden=True)
@commands.is_owner()
async def unload(ctx, ext):
	bot.unload_extension(f'cogs.{ext}')
	print(f'cogs.{ext} unloaded')


@bot.command(hidden=True)
@commands.is_owner()
async def reload(ctx, ext):
	bot.reload_extension(f'cogs.{ext}')
	print(f'cogs.{ext} reloaded')


for extension in ['developer']:
	bot.load_extension(f'cogs.{extension}')

bot.run(TOKEN)
